@@ -44,8 +44,8 @@ def tm_score(coords_1, coords_2, l1, l2):
     sum_1 = 0
     sum_2 = 0
     for i in range(coords_1.shape[0]):
-        sum_1 += 1 / (1 + (np.sqrt(np.sum((coords_1[i] - coords_2[i]) ** 2)) / d1))
-        sum_2 += 1 / (1 + (np.sqrt(np.sum((coords_1[i] - coords_2[i]) ** 2)) / d2))
+        sum_1 += 1 / (1 + (np.sum(coords_1[i] - coords_2[i]) / d1)**2)
+        sum_2 += 1 / (1 + (np.sum(coords_1[i] - coords_2[i]) / d2)**2)
     t1 = (1 / l1) * sum_1
     t2 = (1 / l2) * sum_2
     return max(t1, t2)
@@ -996,7 +996,9 @@ class StructureMultiple:
             .astype(np.float64)
         )
         pd.writePDB(str(output_pdb_folder / f"{reference_name}.pdb"), reference_pdb)
-        for i in range(1, len(self.structures)):
+        for i in range(len(self.structures)):
+            if i == self.reference_structure_index:
+                continue
             name = self.structures[i].name
             pdb = pd.parsePDB(
                 str(self.output_folder / f"cleaned_pdb/{self.structures[i].name}.pdb")
